==> packageinstaller-pkglist-libre_0.1.6.tar.xz: packageinstaller-pkglist-libre/arc-evopro2-theme-antix.pm <==
<?xml version="1.0"?>
<app>

<category>
Themes
</category>

<name>
Arc-EvoPro2 Gtk Theme
</name>

<description>
   <am>antiX 19 GTK theme (Dark)</am>
   <ar>antiX 19 GTK theme (Dark)</ar>
   <be>antiX 19 GTK theme (Dark)</be>
   <bg>antiX 19 GTK theme (Dark)</bg>
   <bn>antiX 19 GTK theme (Dark)</bn>
   <ca>antiX 19 GTK theme (Dark)</ca>
   <cs>antiX 19 GTK theme (Dark)</cs>
   <da>antiX 19 GTK theme (Dark)</da>
   <de>antiX 19 GTK Stil (Dunkel)</de>
   <el>antiX 19 GTK theme (Σκούρο)</el>
   <en>antiX 19 GTK theme (Dark)</en>
   <es_ES>antiX 19 GTK theme (Dark)</es_ES>
   <es>Tema GTK oscuro para antiX 19</es>
   <et>antiX 19 GTK theme (Dark)</et>
   <eu>antiX 19 GTK theme (Dark)</eu>
   <fa>antiX 19 GTK theme (Dark)</fa>
   <fil_PH>antiX 19 GTK theme (Dark)</fil_PH>
   <fi>antiX 19 GTK theme (Dark)</fi>
   <fr_BE>antiX 19 GTK theme (Dark)</fr_BE>
   <fr>antiX 19 GTK thème (Dark)</fr>
   <gl_ES>antiX 19 GTK theme (Dark)</gl_ES>
   <he_IL>antiX 19 GTK theme (Dark)</he_IL>
   <hi>antiX 19 GTK theme (Dark)</hi>
   <hr>antiX 19 GTK theme (Dark)</hr>
   <hu>antiX 19 GTK theme (Dark)</hu>
   <id>antiX 19 GTK theme (Dark)</id>
   <is>antiX 19 GTK theme (Dark)</is>
   <it>Tema GTK (Scuro) di antiX 19</it>
   <ja>antiX 19 GTKテーマ(ダーク)</ja>
   <kk>antiX 19 GTK theme (Dark)</kk>
   <ko>antiX 19 GTK theme (Dark)</ko>
   <lt>antiX 19 GTK theme (Dark)</lt>
   <mk>antiX 19 GTK theme (Dark)</mk>
   <mr>antiX 19 GTK theme (Dark)</mr>
   <nb_NO>antiX 19 GTK theme (Dark)</nb_NO>
   <nb>antiX 19 GTK-tema (mørkt)</nb>
   <nl_BE>antiX 19 GTK theme (Dark)</nl_BE>
   <nl>antiX 19 GTK theme (Dark)</nl>
   <pl>antiX 19 GTK theme (Dark)</pl>
   <pt_BR>Tema Escuro para o antiX 19 GTK</pt_BR>
   <pt>Tema GTK (Escuro) para o antiX 19</pt>
   <ro>antiX 19 GTK theme (Dark)</ro>
   <ru>antiX 19 GTK theme (Dark)</ru>
   <sk>antiX 19 GTK theme (Dark)</sk>
   <sl>antiX 19 GTK theme (Dark)</sl>
   <sq>antiX 19 GTK theme (Dark)</sq>
   <sr>antiX 19 GTK theme (Dark)</sr>
   <sv>antiX 19 GTK tema (Mörk)</sv>
   <th>antiX 19 GTK theme (Dark)</th>
   <tr>antiX 19 GTK theme (Dark)</tr>
   <uk>antiX 19 GTK theme (Dark)</uk>
   <vi>antiX 19 GTK theme (Dark)</vi>
   <zh_CN>antiX 19 GTK theme (Dark)</zh_CN>
   <zh_HK>antiX 19 GTK theme (Dark)</zh_HK>
   <zh_TW>antiX 19 GTK theme (Dark)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
arc-evopro2-theme-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
arc-evopro2-theme-antix
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/arc-evopro2-theme-antix.pm <==
<?xml version="1.0"?>
<app>

<category>
Themes
</category>

<name>
Arc-EvoPro2 Gtk Theme
</name>

<description>
   <am>antiX 19 GTK theme (Dark)</am>
   <ar>antiX 19 GTK theme (Dark)</ar>
   <be>antiX 19 GTK theme (Dark)</be>
   <bg>antiX 19 GTK theme (Dark)</bg>
   <bn>antiX 19 GTK theme (Dark)</bn>
   <ca>antiX 19 GTK theme (Dark)</ca>
   <cs>antiX 19 GTK theme (Dark)</cs>
   <da>antiX 19 GTK theme (Dark)</da>
   <de>antiX 19 GTK Stil (Dunkel)</de>
   <el>antiX 19 GTK theme (Σκούρο)</el>
   <en>antiX 19 GTK theme (Dark)</en>
   <es_ES>antiX 19 GTK theme (Dark)</es_ES>
   <es>Tema GTK oscuro para antiX 19</es>
   <et>antiX 19 GTK theme (Dark)</et>
   <eu>antiX 19 GTK theme (Dark)</eu>
   <fa>antiX 19 GTK theme (Dark)</fa>
   <fil_PH>antiX 19 GTK theme (Dark)</fil_PH>
   <fi>antiX 19 GTK theme (Dark)</fi>
   <fr_BE>antiX 19 GTK thème (Dark)</fr_BE>
   <fr>antiX 19 GTK thème (Dark)</fr>
   <gl_ES>antiX 19 GTK theme (Dark)</gl_ES>
   <he_IL>antiX 19 GTK theme (Dark)</he_IL>
   <hi>antiX 19 GTK theme (Dark)</hi>
   <hr>antiX 19 GTK theme (Dark)</hr>
   <hu>antiX 19 GTK theme (Dark)</hu>
   <id>antiX 19 GTK theme (Dark)</id>
   <is>antiX 19 GTK theme (Dark)</is>
   <it>Tema GTK (Scuro) di antiX 19</it>
   <ja>antiX 19 GTKテーマ(ダーク)</ja>
   <kk>antiX 19 GTK theme (Dark)</kk>
   <ko>antiX 19 GTK theme (Dark)</ko>
   <lt>antiX 19 GTK theme (Dark)</lt>
   <mk>antiX 19 GTK theme (Dark)</mk>
   <mr>antiX 19 GTK theme (Dark)</mr>
   <nb_NO>antiX 19 GTK theme (Dark)</nb_NO>
   <nb>antiX 19 GTK-tema (mørkt)</nb>
   <nl_BE>antiX 19 GTK theme (Dark)</nl_BE>
   <nl>antiX 19 GTK theme (Dark)</nl>
   <pl>antiX 19 GTK theme (Dark)</pl>
   <pt_BR>Tema Escuro para o antiX 19 GTK</pt_BR>
   <pt>Tema GTK (Escuro) para o antiX 19</pt>
   <ro>antiX 19 GTK theme (Dark)</ro>
   <ru>antiX 19 GTK theme (Dark)</ru>
   <sk>antiX 19 GTK theme (Dark)</sk>
   <sl>antiX 19 GTK theme (Dark)</sl>
   <sq>antiX 19 GTK theme (Dark)</sq>
   <sr>antiX 19 GTK theme (Dark)</sr>
   <sv>antiX 19 GTK tema (Mörk)</sv>
   <th>antiX 19 GTK theme (Dark)</th>
   <tr>antiX 19 GTK theme (Dark)</tr>
   <uk>antiX 19 GTK theme (Dark)</uk>
   <vi>antiX 19 GTK theme (Dark)</vi>
   <zh_CN>antiX 19 GTK theme (Dark)</zh_CN>
   <zh_HK>antiX 19 GTK theme (Dark)</zh_HK>
   <zh_TW>antiX 19 GTK theme (Dark)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
arc-evopro2-theme-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
arc-evopro2-theme-antix
</uninstall_package_names>
</app>
